import { AccessLevelList } from '../../shared/access-level';
import { PolicyStatement } from '../../shared';
import { aws_iam as iam } from "aws-cdk-lib";
/**
 * Statement provider for service [q](https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonq.html).
 *
 * @param sid [SID](https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_elements_sid.html) of the statement
 */
export declare class Q extends PolicyStatement {
    servicePrefix: string;
    /**
     * Grants permission to create a user or group assignment for an Amazon Q Developer Profile
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/amazonq/latest/aws-builder-use-ug/security_iam_manage-access-with-policies.html
     */
    toCreateAssignment(): this;
    /**
     * Grants permission to delete a user or group assignment for an Amazon Q Developer Profile
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/amazonq/latest/aws-builder-use-ug/security_iam_manage-access-with-policies.html
     */
    toDeleteAssignment(): this;
    /**
     * Grants permission to get individual messages associated with a specific conversation with Amazon Q
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/amazonq/latest/aws-builder-use-ug/security_iam_manage-access-with-policies.html
     */
    toGetConversation(): this;
    /**
     * Grants permission to Amazon Q to get the identity metadata
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/amazonq/latest/aws-builder-use-ug/security_iam_manage-access-with-policies.html
     */
    toGetIdentityMetadata(): this;
    /**
     * Grants permission to get troubleshooting results with Amazon Q
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/amazonq/latest/aws-builder-use-ug/security_iam_manage-access-with-policies.html
     */
    toGetTroubleshootingResults(): this;
    /**
     * Grants permission to list individual conversations associated with a specific Amazon Q user
     *
     * Access Level: Read
     *
     * https://docs.aws.amazon.com/amazonq/latest/aws-builder-use-ug/security_iam_manage-access-with-policies.html
     */
    toListConversations(): this;
    /**
     * Grants permission to allow Amazon Q to perform actions on your behalf
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/amazonq/latest/aws-builder-use-ug/security_iam_manage-access-with-policies.html
     */
    toPassRequest(): this;
    /**
     * Grants permission to send a message to Amazon Q
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/amazonq/latest/aws-builder-use-ug/security_iam_manage-access-with-policies.html
     */
    toSendMessage(): this;
    /**
     * Grants permission to start a conversation with Amazon Q
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/amazonq/latest/aws-builder-use-ug/security_iam_manage-access-with-policies.html
     */
    toStartConversation(): this;
    /**
     * Grants permission to start a troubleshooting analysis with Amazon Q
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/amazonq/latest/aws-builder-use-ug/security_iam_manage-access-with-policies.html
     */
    toStartTroubleshootingAnalysis(): this;
    /**
     * Grants permission to start a troubleshooting resolution explanation with Amazon Q
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/amazonq/latest/aws-builder-use-ug/security_iam_manage-access-with-policies.html
     */
    toStartTroubleshootingResolutionExplanation(): this;
    /**
     * Grants permission to update a troubleshooting command result with Amazon Q
     *
     * Access Level: Write
     *
     * https://docs.aws.amazon.com/amazonq/latest/aws-builder-use-ug/security_iam_manage-access-with-policies.html
     */
    toUpdateTroubleshootingCommandResult(): this;
    protected accessLevelList: AccessLevelList;
    /**
     * Statement provider for service [q](https://docs.aws.amazon.com/service-authorization/latest/reference/list_amazonq.html).
     *
     */
    constructor(props?: iam.PolicyStatementProps);
}
